@@ -24,11 +24,10 @@ import textwrap
 from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Any, Callable, Sequence
 
-from deprecated import deprecated
 from google.cloud.storage.retry import DEFAULT_RETRY
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.cloud.triggers.gcs import (
     GCSBlobTrigger,
@@ -36,6 +35,7 @@ from airflow.providers.google.cloud.triggers.gcs import (
     GCSPrefixBlobTrigger,
     GCSUploadSessionTrigger,
 )
+from airflow.providers.google.common.deprecated import deprecated
 from airflow.sensors.base import BaseSensorOperator, poke_mode_only
 
 if TYPE_CHECKING:
@@ -137,19 +137,15 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         if event["status"] == "error":
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
         self.log.info("File %s was found in bucket %s.", self.object, self.bucket)
         return True
 
 
 @deprecated(
-    reason=(
-        "Class `GCSObjectExistenceAsyncSensor` is deprecated and will be removed in a future release. "
-        "Please use `GCSObjectExistenceSensor` and set `deferrable` attribute to `True` instead"
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GCSObjectExistenceSensor",
+    instructions="Please use GCSObjectExistenceSensor and set deferrable attribute to True.",
     category=AirflowProviderDeprecationWarning,
 )
 class GCSObjectExistenceAsyncSensor(GCSObjectExistenceSensor):
@@ -188,7 +184,15 @@ def ts_function(context):
     try:
         return context["data_interval_end"]
     except KeyError:
-        return context["dag"].following_schedule(context["execution_date"])
+        from airflow.utils import timezone
+
+        data_interval = context["dag"].infer_automated_data_interval(
+            timezone.coerce_datetime(context["execution_date"])
+        )
+        next_info = context["dag"].next_dagrun_info(data_interval, restricted=False)
+        if next_info is None:
+            return None
+        return next_info.data_interval.start
 
 
 class GCSObjectUpdateSensor(BaseSensorOperator):
@@ -276,15 +280,9 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
                     "Checking last updated time for object %s in bucket : %s", self.object, self.bucket
                 )
                 return event["message"]
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
 
-        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
         message = "No event received in trigger callback"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
         raise AirflowException(message)
 
 
@@ -374,9 +372,6 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
         self.log.info("Resuming from trigger and checking status")
         if event["status"] == "success":
             return event["matches"]
-        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-        if self.soft_fail:
-            raise AirflowSkipException(event["message"])
         raise AirflowException(event["message"])
 
 
@@ -506,13 +501,10 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
                 )
                 return False
 
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
             message = (
                 "Illegal behavior: objects were deleted in "
                 f"{os.path.join(self.bucket, self.prefix)} between pokes."
             )
-            if self.soft_fail:
-                raise AirflowSkipException(message)
             raise AirflowException(message)
 
         if self.last_activity_time:
@@ -575,7 +567,8 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
             )
 
     def execute_complete(self, context: dict[str, Any], event: dict[str, str] | None = None) -> str:
-        """Rely on trigger to throw an exception, otherwise it assumes execution was successful.
+        """
+        Rely on trigger to throw an exception, otherwise it assumes execution was successful.
 
         Callback for when the trigger fires - returns immediately.
 
@@ -583,13 +576,7 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
         if event:
             if event["status"] == "success":
                 return event["message"]
-            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
-            if self.soft_fail:
-                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
 
-        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
         message = "No event received in trigger callback"
-        if self.soft_fail:
-            raise AirflowSkipException(message)
         raise AirflowException(message)
