@@ -16,17 +16,17 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Analytics 360 operators."""
+
 from __future__ import annotations
 
 import csv
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING, Any, Sequence
 
-from deprecated import deprecated
-
 from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
+from airflow.providers.google.common.deprecated import deprecated
 from airflow.providers.google.marketing_platform.hooks.analytics import GoogleAnalyticsHook
 
 if TYPE_CHECKING:
@@ -34,10 +34,9 @@ if TYPE_CHECKING:
 
 
 @deprecated(
-    reason=(
-        "The `GoogleAnalyticsListAccountsOperator` class is deprecated, please use "
-        "`GoogleAnalyticsAdminListAccountsOperator` instead."
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GoogleAnalyticsAdminListAccountsOperator",
+    reason="The Google Analytics API v3 has sunset and is no longer available as of July 1, 2024.",
     category=AirflowProviderDeprecationWarning,
 )
 class GoogleAnalyticsListAccountsOperator(BaseOperator):
@@ -54,10 +53,6 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
         and for python client
         http://googleapis.github.io/google-api-python-client/docs/dyn/analytics_v3.management.accounts.html#list
 
-    .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:GoogleAnalyticsListAccountsOperator`
-
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param impersonation_chain: Optional service account to impersonate using short-term
@@ -101,10 +96,9 @@ class GoogleAnalyticsListAccountsOperator(BaseOperator):
 
 
 @deprecated(
-    reason=(
-        "The `GoogleAnalyticsGetAdsLinkOperator` class is deprecated, please use "
-        "`GoogleAnalyticsAdminGetGoogleAdsLinkOperator` instead."
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GoogleAnalyticsAdminGetGoogleAdsLinkOperator",
+    reason="The Google Analytics API v3 has sunset and is no longer available as of July 1, 2024.",
     category=AirflowProviderDeprecationWarning,
 )
 class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
@@ -119,9 +113,6 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
         Check official API docs:
         https://developers.google.com/analytics/devguides/config/mgmt/v3/mgmtReference/management/webPropertyAdWordsLinks/get
 
-    .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:GoogleAnalyticsGetAdsLinkOperator`
 
     :param account_id: ID of the account which the given web property belongs to.
     :param web_property_ad_words_link_id: Web property-Google Ads link ID.
@@ -180,10 +171,9 @@ class GoogleAnalyticsGetAdsLinkOperator(BaseOperator):
 
 
 @deprecated(
-    reason=(
-        "The `GoogleAnalyticsRetrieveAdsLinksListOperator` class is deprecated, please use "
-        "`GoogleAnalyticsAdminListGoogleAdsLinksOperator` instead."
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GoogleAnalyticsAdminListGoogleAdsLinksOperator",
+    reason="The Google Analytics API v3 has sunset and is no longer available as of July 1, 2024.",
     category=AirflowProviderDeprecationWarning,
 )
 class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
@@ -198,10 +188,6 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
         Check official API docs:
         https://developers.google.com/analytics/devguides/config/mgmt/v3/mgmtReference/management/webPropertyAdWordsLinks/list#http-request
 
-    .. seealso::
-        For more information on how to use this operator, take a look at the guide:
-        :ref:`howto/operator:GoogleAnalyticsRetrieveAdsLinksListOperator`
-
     :param account_id: ID of the account which the given web property belongs to.
     :param web_property_id: Web property UA-string to retrieve the Google Ads links for.
     :param impersonation_chain: Optional service account to impersonate using short-term
@@ -254,10 +240,9 @@ class GoogleAnalyticsRetrieveAdsLinksListOperator(BaseOperator):
 
 
 @deprecated(
-    reason=(
-        "The `GoogleAnalyticsDataImportUploadOperator` class is deprecated, please use "
-        "`GoogleAnalyticsAdminCreateDataStreamOperator` instead."
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GoogleAnalyticsAdminCreateDataStreamOperator",
+    reason="The Google Analytics API v3 has sunset and is no longer available as of July 1, 2024.",
     category=AirflowProviderDeprecationWarning,
 )
 class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
@@ -361,10 +346,9 @@ class GoogleAnalyticsDataImportUploadOperator(BaseOperator):
 
 
 @deprecated(
-    reason=(
-        "The `GoogleAnalyticsDeletePreviousDataUploadsOperator` class is deprecated, please use "
-        "`GoogleAnalyticsAdminDeleteDataStreamOperator` instead."
-    ),
+    planned_removal_date="November 01, 2024",
+    use_instead="GoogleAnalyticsAdminDeleteDataStreamOperator",
+    reason="The Google Analytics API v3 has sunset and is no longer available as of July 1, 2024.",
     category=AirflowProviderDeprecationWarning,
 )
 class GoogleAnalyticsDeletePreviousDataUploadsOperator(BaseOperator):
